@@ -8,7 +8,7 @@ package Struct::Dumb;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Carp;
 
@@ -71,7 +71,9 @@ structures, uses nothing outside of core. It's intended simply to be a
 slightly nicer way to store data structures, where otherwise you might be
 tempted to abuse a hash, complete with the risk of typoing key names. The
 constructor will C<croak> if passed the wrong number of arguments, as will
-attempts to refer to fields that don't exist.
+attempts to refer to fields that don't exist. Accessor-mutators will C<croak>
+if invoked with extra arguments; a likely bug in case of mutations, or
+attempts to invoke a stored C<CODE> reference.
 
  $ perl -E 'use Struct::Dumb; struct Point => [qw( x y )]; Point(30)'
  usage: main::Point($x, $y) at -e line 1
@@ -79,6 +81,9 @@ attempts to refer to fields that don't exist.
  $ perl -E 'use Struct::Dumb; struct Point => [qw( x y )]; Point(10,20)->z'
  main::Point does not have a 'z' field at -e line 1
 
+ $ perl -E 'use Struct::Dumb; struct Point => [qw( x y )]; Point(1,2)->x(3)'
+ main::Point->x invoked with arguments at -e line 1.
+
 =head2 CONSTRUCTOR FORMS
 
 The C<struct> and C<readonly_struct> declarations create two different kinds
@@ -202,7 +207,8 @@ sub _struct
 
    require overload;
    $pkg->overload::OVERLOAD(
-      '@{}' => sub { croak "Cannot use $pkg as an ARRAY reference" },
+      '@{}'  => sub { croak "Cannot use $pkg as an ARRAY reference" },
+      'bool' => sub { 1 },
    );
 }
 
